Description Usage Arguments Details Value Note See Also Examples
Function samples frequency vectors from the selected frequency distribution law.
1 2 3 4 5 6 7 8 9 |
m |
Number of frequency vectors. |
n |
Length of frequency vector. |
sigma |
Data variance, a scalar or a vector in the case of the Gaussian distribution mixture. |
alpha |
Variance weights. By default all are equal to 1. |
TypeDist |
Frequency distribution type. Possible values: "G" (Gaussian), "FG" (Folded Gaussian radial) or "AR" (Adapted radius). Default is "AR". |
ncores |
Number of cores. Multicore computation should be used only when the data is a mixture of Gaussian distributions. |
parallel |
logical parameter that defines whether to perform the parallel computations. Default is FALSE. |
The frequency vectors w_1, …, w_m are randomly sampled from
the predefined frequency distribution. The distribution law can be either
N(0, Σ^{-1}) (typeDist = "G") or p_R \cdot \varphi \cdot Σ^{-\frac{1}{2}}
(typeDist = c("FG", "AR")), where \varphi is a vector
uniformly distributed on the unit sphere, Σ is a diagonal matrix with the data variance sigma on the diagonal
and where p_R is the radius density function.
For "FG" the radius distribution is N(0,1)^+ and for "AR"
p_R = C \cdot (R^2 + \frac{R^4}{4})^{0.5} \cdot \exp{(-0.5 \cdot R^2)}, where C is a normalization constant.
A matrix m x n, with frequency vectors in rows.
The implemented method of the frequency sampling has been proposed in \insertRefDBLP:journals/corr/KerivenBGP16chickn.
EstimSigma, GenerateFrequencies, Sketch
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.